@@ -3,9 +3,9 @@
 #' Function to provide priors and their parameters to \code{\link{bvar}}. Used
 #' for adjusting the parameters treated as hyperparameters, the Minnesota prior
 #' and adding various dummy priors through the ellipsis parameter.
-#' Note that treating \eqn{\psi} (\emph{psi}) as a hyperparameter in a model
-#' with many variables may lead to very low acceptance rates and thus hinder
-#' convergence.
+#' Note that treating \eqn{\psi}{psi} (\emph{psi}) as a hyperparameter in a
+#' model with many variables may lead to very low acceptance rates and thus
+#' hinder convergence.
 #'
 #' @param hyper Character vector. Used to specify the parameters to be treated
 #' as hyperparameters. May also be set to \code{"auto"} or \code{"full"} for
@@ -14,30 +14,28 @@
 #' names of additional dummy priors included via \emph{...}.
 #' @param mn List of class \code{"bv_minnesota"}. Options for the Minnesota
 #' prior, set via \code{\link{bv_mn}}.
-#' @param ... Optional lists of class \code{"bv_dummy"} with options for
-#' dummy priors. \strong{Must be assigned a name in the function call}. Created
+#' @param ... Optional lists of class \code{bv_dummy} with options for
+#' dummy priors. \bold{Must be assigned a name in the function call}. Created
 #' with \code{\link{bv_dummy}}.
-#' @param x Object of class \code{bv_priors}, \code{bv_dummy} or \code{bv_psi}.
-#' @param indent Logical scalar. Used internally to format printed outputs.
 #'
 #' @return Returns a named list of class \code{bv_priors} with options for
 #' \code{\link{bvar}}.
 #'
-#' @keywords VAR BVAR priors minnesota dummy
+#' @keywords priors hierarchical Minnesota dummy settings
 #'
 #' @seealso \code{\link{bv_mn}}; \code{\link{bv_dummy}}
 #'
 #' @export
 #'
 #' @examples
-#' # Extending hyperparameters to the full Minnesota prior
-#' bv_priors(c("lambda", "alpha", "psi"))
+#' # Extend the hyperparameters to the full Minnesota prior
+#' bv_priors(hyper = c("lambda", "alpha", "psi"))
 #' # Alternatively
-#' bv_priors("full")
+#' # bv_priors("full")
 #'
-#' # Adding a dummy prior via `bv_dummy()`
+#' # Add a dummy prior via `bv_dummy()`
 #'
-#' # First create a single-unit-root prior
+#' # Re-create the single-unit-root prior
 #' add_sur <- function(Y, lags, par) {
 #'   sur <- if(lags == 1) {Y[1, ] / par} else {
 #'     colMeans(Y[1:lags, ]) / par
@@ -49,17 +47,17 @@
 #' }
 #' sur <- bv_dummy(mode = 1, sd = 1, min = 0.0001, max = 50, fun = add_sur)
 #'
-#' # Then add the prior to `bv_priors()`
-#' priors_dum <- bv_priors(hyper = "auto", sur = sur)
+#' # Add the new prior
+#' bv_priors(hyper = "auto", sur = sur)
 bv_priors <- function(
   hyper = "auto",
   mn = bv_mn(),
   ...) {
 
-  # Check inputs ------------------------------------------------------------
+  # Check inputs ---
 
-  if(!is.null(mn) && !inherits(mn, "bv_minnesota")) {
-    stop("Please use `bv_mn()` to set the minnesota prior.")
+  if(!inherits(mn, "bv_minnesota")) { # Require Minnesota prior
+    stop("Please use `bv_mn()` to set the Minnesota prior.")
   }
   dots <- list(...)
   if(!all(vapply(dots, inherits, TRUE, "bv_dummy"))) {
@@ -76,16 +74,18 @@ bv_priors <- function(
     }
   }
 
-
-  # Output ------------------------------------------------------------------
+  # Prepare output ---
 
   out <- if(!is.null(mn)) {
-    list(hyper = hyper, lambda = mn[["lambda"]], alpha = mn[["alpha"]],
-         psi = mn[["psi"]], var = mn[["var"]], b = mn[["b"]], ...)
+    structure(list(hyper = hyper,
+      lambda = mn[["lambda"]], alpha = mn[["alpha"]],
+      psi = mn[["psi"]], var = mn[["var"]], b = mn[["b"]],
+      ..., dummy = names(list(...))
+      ), class = "bv_priors")
   } else {
-    list(hyper = hyper, ...)
+    structure(list(hyper = hyper,
+      ..., dummy = names(list(...))), class = "bv_priors")
   }
-  class(out) <- "bv_priors"
 
   return(out)
 }
