@@ -1,7 +1,7 @@
 #' Forecast computation
 #'
-#' Compute unconditional forecasts from the VAR's posterior draws obtained via
-#' \code{\link{draw_post}}.
+#' Compute unconditional forecasts without shocks from the VAR's posterior draws
+#' obtained via \code{\link{draw_post}}.
 #'
 #' @param Y Numeric matrix (\eqn{N * M}).
 #' @param K Integer scalar. Columns of \emph{X}, i.e. \eqn{M * lags + 1}.
@@ -14,11 +14,9 @@
 #' the model in state space representation.
 #' @param beta_const Numeric vector. Posterior draw of the VAR coefficients
 #' corresponding to the constant of the model.
-#' @param sigma Numeric matrix. Posterior draw of the vcov-matrix of the
-#' model.
-#' @param conditional Not yet implemented.
 #'
-#' @return Returns a matrix containing forecasts for all variables in the model.
+#' @return Returns a matrix containing forecasts (without shocks) for all
+#' variables in the model.
 #'
 #' @importFrom stats rnorm
 #'
@@ -26,19 +24,16 @@
 compute_fcast <- function(
   Y, K, M, N, lags,
   horizon,
-  beta_comp, beta_const,
-  sigma,
-  conditional = FALSE) {
+  beta_comp, beta_const) {
 
   Y_f <- matrix(NA, horizon + 1, K - 1)
-  Y_f[1, ] <- sapply(t(Y[N:(N - lags + 1), ]), c)
+  Y_f[1, ] <- vapply(t(Y[N:(N - lags + 1), ]), c, numeric(1L))
 
-  for(i in 2:(1 + horizon)) {
-    Y_f[i, ] <- Y_f[i - 1, ] %*% t(beta_comp) +
-      c(beta_const, rep(0, M * (lags - 1))) +
-      c(sigma %*% rnorm(M), rep(0, M * (lags - 1)))
+  for(i in seq.int(2, 1 + horizon)) {
+    Y_f[i, ] <- tcrossprod(Y_f[i - 1, ], beta_comp) +
+      c(beta_const, rep(0, M * (lags - 1))) # Maybe go back to normal beta
   }
 
-  # Remove Y_t and further lags from Y_f to get the forecast
-  return(Y_f[2:(1 + horizon), 1:M])
+  # Remove Y_t and lagged variables
+  return(Y_f[-1, 1:M])
 }
